Module toggle

Module toggle 

Enable/Disable mods.

Functions

generate_config
Generates an empty, enabled config to the given path.
get_mod_enabled
Gets whether a mod is enabled given its mod path
toggle_mod
Toggle a mod to a given enabled value. Also supports applying this action recursively.