Enable/Disable mods.
Functions
- generate_
config - Generates an empty, enabled config to the given path.
- get_
mod_ enabled - Gets whether a mod is enabled given its mod path
- toggle_
mod - Toggle a mod to a given enabled value. Also supports applying this action recursively.